@@ -6,10 +6,7 @@ NULL
 #' Prepare and show concordances / keyword-in-context (kwic). The same result can be achieved by 
 #' applying the kwich method on either a partition or a context object.
 #' 
-#' If you enter \code{"kwic()"} on the console, a shiny application will be launched. The app
-#' will offer partition objects present in the global environment.
-#' 
-#' @param .Object a \code{partition} or \code{context} object, if \code{missing}, a shiny application will be launched
+#' @param .Object a \code{partition} or \code{context} object
 #' @param query a query, CQP-syntax can be used
 #' @param cqp either logical (TRUE if query is a CQP query), or a
 #'   function to check whether query is a CQP query or not (defaults to is.query
@@ -51,7 +48,7 @@ setGeneric("kwic", function(.Object, ...){standardGeneric("kwic")})
 #' @exportMethod kwic
 #' @docType methods
 #' @rdname kwic
-setMethod("kwic", "context", function(.Object, meta=getOption("polmineR.meta"), cpos=FALSE, neighbor=NULL, verbose=FALSE){
+setMethod("kwic", "context", function(.Object, meta = getOption("polmineR.meta"), cpos = TRUE, neighbor = NULL, verbose=FALSE){
   
   tab <- lapply(
     c("left", "node", "right"),
@@ -60,45 +57,41 @@ setMethod("kwic", "context", function(.Object, meta=getOption("polmineR.meta"),
         .Object@cpos, function(x) {
           getTokenStream(
             x[[what]],
-            corpus=.Object@corpus,
-            encoding=.Object@encoding,
-            pAttribute=.Object@pAttribute,
-            collapse=" ",
+            corpus = .Object@corpus,
+            encoding = .Object@encoding,
+            pAttribute = .Object@pAttribute,
+            collapse = " ",
             beautify=TRUE
             )
         }))
     }
   )
-  tab <- data.frame(tab, stringsAsFactors=FALSE)
+  tab <- data.frame(tab, stringsAsFactors = FALSE)
   colnames(tab) <- c("left", "node", "right")
   
-  if (!is.null(meta)){
-    metainformation <- lapply(
-      meta,
-      function(metadat){
-        # sAttr <- paste(.Object@corpus, ".", metadat, sep="")
-        strucs <- CQI$cpos2struc(.Object@corpus, metadat, unlist(lapply(.Object@cpos, function(x)x$node[1])))
-        as.utf8(CQI$struc2str(.Object@corpus, metadat, strucs))
-      }
-    )
-    metainformation <- data.frame(metainformation, stringsAsFactors = FALSE)
-    colnames(metainformation) <- meta
-    tab <- data.frame(metainformation, tab)  
-  }
-  
   if (length(neighbor) > 0){
-    tab <- tab[grep(neighbor, apply(tab, 1, function(x)paste(x[length(x)-2], x[length(x)]))),]
+    rowsToKeep <- grep(neighbor, apply(tab, 1, function(x)paste(x[length(x)-2], x[length(x)])))
+    tab <- tab[rowsToKeep,]
+    if (length(rowsToKeep) > 0){
+      .Object@cpos <- lapply(rowsToKeep, function(i) .Object@cpos[[i]])
+    } else {
+      .Object@cpos <- NULL
+    }
   } 
   
+  if (is.null(meta)) meta <- character()
   conc <- new(
     'kwic',
-    corpus=.Object@corpus, left=.Object@left, right=.Object@right,
-    table=tab,
-    metadata=ifelse(is.null(meta), as.character(c()), meta),
-    encoding=.Object@encoding
+    corpus = .Object@corpus, left = .Object@left, right = .Object@right,
+    table = tab,
+    metadata = meta,
+    encoding = .Object@encoding
     )
   if (cpos == TRUE) conc@cpos <- .Object@cpos
-  if (!is.null(neighbor) || !length(neighbor) == 0) {conc@neighbor <- neighbor}
+  
+  conc <- enrich(conc, meta)
+  if (!is.null(neighbor) || !length(neighbor) == 0) conc@neighbor <- neighbor
+  
   conc
 })
 
@@ -106,48 +99,39 @@ setMethod("kwic", "context", function(.Object, meta=getOption("polmineR.meta"),
 #' @rdname kwic
 #' @exportMethod kwic
 setMethod("kwic", "partition", function(
-  .Object, query, cqp=is.cqp,
+  .Object, query, cqp = is.cqp,
   left = getOption("polmineR.left"),
   right = getOption("polmineR.right"),
   meta = getOption("polmineR.meta"),
-  pAttribute="word", sAttribute=NULL, cpos=TRUE,
-  neighbor=NULL,
-  verbose=TRUE
+  pAttribute = "word", sAttribute = NULL, cpos = TRUE,
+  neighbor = NULL,
+  verbose = TRUE
 ){
   ctxt <- context(
-    .Object=.Object, query=query, cqp=cqp,
-    pAttribute=pAttribute, sAttribute=sAttribute,
-    left=left, right=right,
-    method=NULL, count=FALSE, verbose=verbose
+    .Object = .Object, query = query, cqp = cqp,
+    pAttribute = pAttribute, sAttribute = sAttribute,
+    left = left, right = right,
+    method = NULL, count = FALSE, verbose = verbose
   )
   if (is.null(ctxt)){
     message("... no occurrence of query")
     return(NULL)
     }
-  kwic(.Object=ctxt, meta=meta, neighbor=neighbor, cpos=cpos)
+  kwic(.Object = ctxt, meta = meta, neighbor = neighbor, cpos = cpos)
 })
 
-#' @rdname kwic
-setMethod("kwic", "missing", function(.Object, ...){
-  if (requireNamespace("shiny", quietly=TRUE)){
-    shiny::runApp(system.file("shiny", "kwic", package="polmineR"), launch.browser=TRUE)  
-  } else {
-    message("package shiny not available")
-  }
-  
-})
 
 #' @rdname kwic
 setMethod("kwic", "character", function(
-  .Object, query, cqp=is.cqp,
-  left=getOption("polmineR.left"),
-  right=getOption("polmineR.right"),
-  meta=getOption("polmineR.meta"),
-  pAttribute="word", sAttribute=NULL, cpos=FALSE,
-  neighbor=NULL,
-  verbose=TRUE
+  .Object, query, cqp = is.cqp,
+  left = getOption("polmineR.left"),
+  right = getOption("polmineR.right"),
+  meta = getOption("polmineR.meta"),
+  pAttribute = "word", sAttribute = NULL, cpos = TRUE,
+  neighbor = NULL,
+  verbose = TRUE
 ){
-  hits <- cpos(.Object, query=query, cqp=cqp, pAttribute=pAttribute, verbose=FALSE)
+  hits <- cpos(.Object, query = query, cqp = cqp, pAttribute = pAttribute, verbose=FALSE)
   if (is.null(hits)) {
     message("sorry, not hits")
     return(NULL)
@@ -167,14 +151,14 @@ setMethod("kwic", "character", function(
     )
   ctxt <- new(
     "context",
-    count=nrow(hits), stat=data.table(),
-    corpus=.Object,
-    left=left, right=right, 
-    cpos=cposList,
-    pAttribute=pAttribute,
-    encoding=parseRegistry(.Object)[["charset"]]
+    count = nrow(hits), stat = data.table(),
+    corpus = .Object,
+    left = left, right = right, 
+    cpos = cposList,
+    pAttribute = pAttribute,
+    encoding = parseRegistry(.Object)[["charset"]]
     )
   if (!is.null(sAttribute)) ctxt@sAttribute <- sAttribute
-  kwic(.Object=ctxt, meta=meta, neighbor=neighbor, cpos=cpos)
+  kwic(.Object = ctxt, meta = meta, neighbor = neighbor, cpos = cpos)
 })
 
