@@ -41,3 +41,20 @@ setMethod("as.data.frame", "kwic", function(x){
   )
 })
 
+#' @rdname kwic-class
+setMethod("enrich", "kwic", function(object, meta = NULL){
+  if (length(meta) > 0){
+    metainformation <- lapply(
+      meta,
+      function(metadat){
+        strucs <- CQI$cpos2struc(object@corpus, metadat, unlist(lapply(object@cpos, function(x)x$node[1])))
+        as.utf8(CQI$struc2str(object@corpus, metadat, strucs))
+      }
+    )
+    metainformation <- data.frame(metainformation, stringsAsFactors = FALSE)
+    colnames(metainformation) <- meta
+    object@table <- data.frame(metainformation, object@table)
+    object@metadata <- c(meta, object@metadata)
+  }
+  object
+})
\ No newline at end of file
